@@ -4,11 +4,11 @@ import cffi
 
 
 cwd = os.path.abspath(os.path.dirname(__file__))
-sources = os.path.join(cwd, 'monocypher-3.1.1-src/')
+sources = os.path.join(cwd, 'monocypher-3.1.2-src/')
 
 cdefs_file = os.path.join(cwd, 'monocypher_exposed.h')
 include_dir = sources
-sources     = glob.glob(os.path.join(sources, '*.c'))
+sources     = glob.glob(os.path.join(sources, '**/*.c'), recursive=True)
 
 ffi = cffi.FFI()
 ffi.set_source(
@@ -16,10 +16,14 @@ ffi.set_source(
     '''
 #include <stdlib.h>
 #include <monocypher.h>
+#include <optional/monocypher-ed25519.h>
     ''',
     sources=sources,
     include_dirs=[include_dir],
-    extra_compile_args=['-std=c99', '-O3', '-march=native'],
 )
 with open(cdefs_file, 'r') as fp:
     ffi.cdef(fp.read())
+
+
+if __name__ == "__main__":
+    ffi.compile(verbose=True)
